@@ -183,7 +183,7 @@ namespace Oxygen
         void setFollowMouseDuration( int duration ) override
         {
             _followMouseDuration = duration;
-            foreach( const DataMap<MenuBarDataV2>::Value& value, _data )
+            for ( const DataMap<MenuBarDataV2>::Value &value : std::as_const(_data) )
             { if( value ) value.data()->setFollowMouseDuration( duration ); }
         }
 
