@@ -23,11 +23,7 @@ namespace Oxygen
         DemoWidget( parent )
     {
         setLayout( new QVBoxLayout() );
-#if QT_VERSION < QT_VERSION_CHECK(5, 13, 0)
-        layout()->setMargin(0);
-#else
         layout()->setContentsMargins(0, 0, 0, 0);
-#endif
         QMenuBar* menuBar = new QMenuBar( this );
         layout()->addWidget( menuBar );
 
@@ -78,7 +74,8 @@ namespace Oxygen
         if( true )
         {
             // slide windows
-            foreach( QMdiSubWindow* window, ui.mdiArea->findChildren<QMdiSubWindow*>() )
+            const auto children = ui.mdiArea->findChildren<QMdiSubWindow*>();
+            for ( QMdiSubWindow *window : children )
             {
                 simulator().click( window );
                 simulator().slide( window, QPoint( 20, 20 ) );
@@ -89,10 +86,12 @@ namespace Oxygen
 
         if( true )
         {
-            foreach( QAbstractButton* button, ui.toolBox->findChildren<QAbstractButton*>() )
+            const auto children = ui.toolBox->findChildren<QAbstractButton*>();
+
+            for ( QAbstractButton* button : children )
             { simulator().click( button ); }
 
-            foreach( QAbstractButton* button, ui.toolBox->findChildren<QAbstractButton*>() )
+            for ( QAbstractButton *button : children )
             { simulator().click( button ); }
         }
 
