@@ -20,7 +20,7 @@ namespace Oxygen
         public:
 
         //* constructor
-        explicit StylePlugin(QObject *parent = 0):
+        explicit StylePlugin(QObject *parent = nullptr):
             QStylePlugin(parent)
         {}
 
